#
# spec file for package edje
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           edje
Version:        1.7.4
Release:        17.1
Summary:        Abstract GUI layout and animation object library
License:        BSD-2-Clause and GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://www.enlightenment.org
Source:         %{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  doxygen
BuildRequires:  ecore-devel >= %{version}
BuildRequires:  eet-devel >= %{version}
BuildRequires:  eina-devel >= %{version}
BuildRequires:  embryo-devel >= %{version}
BuildRequires:  evas-devel >= %{version}
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  fontconfig-devel
BuildRequires:  pkgconfig(freetype2)
%if 0%{?suse_version} >= 201210
BuildRequires:  lua51-devel
%else
BuildRequires:  lua-devel < 5.2
%endif
BuildRequires:  pkgconfig
BuildRequires:  python >= 2.5

%description
Abstract GUI layout and animation object library. Part of Enlightenment Foundation Libraries.

%package -n libedje1
Summary:        Edje Dynamic Libraries
Group:          System/Libraries

%description -n libedje1
Headers, static libraries, test programs and documentation for edje

%package devel
Summary:        Edje headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       edje-utils = %{version}
Requires:       libedje1 = %{version}
%if 0%{?suse_version} >= 201210
Requires:       lua51-devel
%else
Requires:       lua-devel < 5.2
%endif
Requires:       ecore-devel >= %{version}
Requires:       eet-devel >= %{version}
Requires:       eina-devel >= %{version}
Requires:       embryo-devel >= %{version}
Requires:       evas-devel >= %{version}

%description devel
Headers, static libraries, test programs and documentation for eina

%package utils
Summary:        Edje utils script to convert import from gimp and inkscape
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       python >= 2.5

%description utils
Edje utils script to convert import from gimp and inkscape. Part of edje library.

%package doc-html
Summary:        HTML documentation of Edje
Group:          Documentation/HTML

%description doc-html
Documentation of Edje library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Edje
Group:          Documentation/Man

%description doc-man
Documentation of Edje library in form of man pages.

%prep
%setup -q

%build
%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

%post -n libedje1 -p /sbin/ldconfig

%postun -n libedje1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/edje_*
%{_datadir}/mime/packages/edje.xml
%dir %{_libdir}/edje

%files -n libedje1
%defattr(-, root, root)
%{_libdir}/libedje.so.1*

%files devel
%defattr(-, root, root)
%{_includedir}/edje-1/
%{_libdir}/pkgconfig/edje.pc
%{_libdir}/libedje.so
%{_datadir}/edje/

%files utils
%defattr(-,root,root)
%{_bindir}/inkscape2edc
%{_libdir}/edje/utils

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-17.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Edje 1.7.3:
  * Lua 5.2 support added, still works fine with 5.1.
  * Before cursor is moved by mouse_down, imf_context_reset
    should be called with current cursor position.
  * Backport from 78587 in trunk.
  * Fix inheriting groups with programs that have after
    programs where after programs are duplicated in the list.
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Mon Dec 10 2012 sleep_walker@suse.cz
- fix condition for lua version
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Sat Nov 24 2012 sleep_walker@suse.cz
- simplify make install
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
  Fixes:
  * fix scale_set with edje containing boxes and/or tables
  * fix edje_cc to use max, not default compression
  * fix edje_text_class_set to update the text classes correctly.
  * fix to not update map uv for proxy
  * fix to not segv on inheriting group lookups
- remove patch from 76449 this issue was fixed for 1.7.2
* Wed Nov 21 2012 sleep_walker@suse.cz
- removed conditions for SLE10 and CentOS5 as these are not build
  targets anymore
- alter description a bit
* Wed Nov 21 2012 sleep_walker@suse.cz
- clean up the spec
- add patch from 76449 needed for alpha4
* Tue Nov 20 2012 sleep_walker@suse.cz
- attempt to fix license
* Tue Nov 20 2012 sleep_walker@suse.cz
- spec file clean up
- reworking make install acording to other packages
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Sat Sep 22 2012 sleep_walker@suse.cz
- make_install --> makeinstall
* Thu Sep 20 2012 sleep_walker@suse.cz
- change pkgconfig dependency to package name
* Tue Sep 27 2011 tcech@suse.com
- change pkgconfig symbols to package names
- add fontconfig and freetype dependencies
* Tue Sep 27 2011 jreidinger@suse.com
- update to 1.0.1
- spec file clean up
- split away tools in python for conversion
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package, version 1.0.0
